@@ -8,16 +8,16 @@
 
 namespace procman
 {
-  class IconThemeWrapper
-  {
-  public:
-    // returns 0 instead of raising an exception
-    Glib::RefPtr<Gdk::Pixbuf>
-    load_icon(const Glib::ustring& icon_name, int size, Gtk::IconLookupFlags flags) const;
+    class IconThemeWrapper
+    {
+      public:
+        // returns 0 instead of raising an exception
+        Glib::RefPtr<Gdk::Pixbuf>
+            load_icon(const Glib::ustring& icon_name, int size) const;
 
-    const IconThemeWrapper* operator->() const
-    { return this; }
-  };
+        const IconThemeWrapper* operator->() const
+        { return this; }
+    };
 }
 
 #endif // H_PROCMAN_ICONTHEMEWRAPPER_H_1185707711
